Package: howler
Type: Package
Title: 'Shiny' Extension of 'howler.js'
Version: 0.3.0
Authors@R: c(
    person("Ashley", "Baldry", email = "arbaldry91@gmail.com", role = c("aut", "cre")),
    person("James", "Simpson", role = "aut", comment = "Creator of howler.js")
    )
Description: Audio interactivity within 'shiny' applications using 'howler.js'. Enables the
    status of the audio player to be sent from the UI to the server, and events such as
    playing and pausing the audio can be triggered from the server.
License: MIT + file LICENSE
URL: https://github.com/ashbaldry/howler,
        https://github.com/goldfire/howler.js
BugReports: https://github.com/ashbaldry/howler/issues
Encoding: UTF-8
Imports: shiny, htmlwidgets
Suggests: rmarkdown, knitr, chromote, shinytest2, globals, testthat (>=
        3.0.0)
Language: en-GB
RoxygenNote: 7.3.1
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-06-04 18:49:26 UTC; arbal
Author: Ashley Baldry [aut, cre],
  James Simpson [aut] (Creator of howler.js)
Maintainer: Ashley Baldry <arbaldry91@gmail.com>
Repository: CRAN
Date/Publication: 2024-06-04 19:00:02 UTC
Built: R 4.6.0; ; 2026-04-29 03:41:55 UTC; unix
