# Generated by roxygen2: do not edit by hand

export(addTrack)
export(availableHowlerExamples)
export(changeHowlSpeed)
export(changeTrack)
export(deleteTrack)
export(howler)
export(howlerBackButton)
export(howlerBasicModuleUI)
export(howlerButton)
export(howlerCurrentTrack)
export(howlerDurationTime)
export(howlerForwardButton)
export(howlerModuleServer)
export(howlerModuleUI)
export(howlerNextButton)
export(howlerOutput)
export(howlerPauseButton)
export(howlerPlayButton)
export(howlerPlayPauseButton)
export(howlerPreviousButton)
export(howlerSeekSlider)
export(howlerSeekTime)
export(howlerStopButton)
export(howlerVolumeDownButton)
export(howlerVolumeSlider)
export(howlerVolumeToggleButton)
export(howlerVolumeUpButton)
export(pauseHowl)
export(playHowl)
export(playSound)
export(renderHowler)
export(runHowlerExample)
export(seekHowl)
export(stopHowl)
export(togglePlayHowl)
import(htmlwidgets)
import(shiny)
